% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/Vlnplots.R
\name{VlnPlot2}
\alias{VlnPlot2}
\alias{VlnPlot2.Seurat}
\alias{VlnPlot2.default}
\title{Enhanced Violin Plot}
\usage{
VlnPlot2(object, ...)

\method{VlnPlot2}{Seurat}(
  seu,
  features,
  group.by = NULL,
  split.by = NULL,
  cells = NULL,
  slot = "data",
  assay = NULL,
  priority = c("expr", "none"),
  cols = "light",
  load.cols = TRUE,
  ncol = NULL,
  nrow = NULL,
  lab_fill = "group",
  scales = "free_y",
  style = c("fill", "outline"),
  violin = T,
  box = T,
  width = 0.9,
  show.mean = FALSE,
  mean_colors = c("red", "blue"),
  pt = T,
  hide.outlier = F,
  pt.style = c("jitter", "quasirandom"),
  pt.size = 0.2,
  pt.alpha = 1,
  strip.position = "top",
  stat.method = c("none", "wilcox.test", "t.test"),
  stats.method = NULL,
  p.adjust.method = "holm",
  label = c("p.signif", "p", "p.adj", "p.format"),
  comparisons = NULL,
  hide.ns = TRUE,
  step.increase = 0.12,
  tip.length = 0.03,
  angle = NULL,
  hjust = NULL,
  vjust = NULL,
  ...
)

\method{VlnPlot2}{default}(
  matr,
  f,
  f2 = NULL,
  features = NULL,
  t = F,
  cols = "light",
  ncol = NULL,
  nrow = NULL,
  lab_fill = "group",
  scales = "free_y",
  style = c("fill", "outline"),
  violin = T,
  box = T,
  width = 0.9,
  show.mean = FALSE,
  mean_colors = c("red", "blue"),
  pt = T,
  hide.outlier = F,
  pt.style = c("jitter", "quasirandom"),
  pt.size = 0.2,
  pt.alpha = 1,
  strip.position = "top",
  stat.method = c("none", "wilcox.test", "t.test"),
  stats.method = NULL,
  p.adjust.method = "holm",
  label = c("p.signif", "p", "p.adj", "p.format"),
  comparisons = NULL,
  hide.ns = TRUE,
  step.increase = 0.12,
  tip.length = 0.03,
  angle = NULL,
  hjust = NULL,
  vjust = NULL,
  ...
)
}
\arguments{
\item{object}{An object, either a Seurat object or matrix.}

\item{...}{Further arguments passed to the \code{\link[ggpubr:stat_pvalue_manual]{ggpubr::stat_pvalue_manual()}}.}

\item{seu}{A Seurat object. Only applicable for the Seurat method.}

\item{features}{Features to depict, such as gene expression, metrics, PC scores, or any data obtainable via `FetchData()`. Default: NULL (all features in matrix).}

\item{group.by}{A variable from `meta.data` for grouping or a character vector of equal length as the number of cells. Only applicable for the Seurat method.}

\item{split.by}{A variable from `meta.data` to bifurcate the violin plots. Only applicable for the Seurat method.}

\item{cells}{Cell identifiers for use. Defaults to all cells. Only applicable for the Seurat method.}

\item{slot}{Slot to retrieve feature data from. Only applicable for the Seurat method.}

\item{assay}{Name of the assay to employ. Defaults to the active assay. Only applicable for the Seurat method.}

\item{priority}{If set to "expr", extracts data from the expression matrix over `meta.data`. Only applicable for the Seurat method.}

\item{cols}{Flexible color settings for the plot, accepting a variety of inputs:

    - Eight color_pro styles: "default", "light", "pro_red", "pro_yellow", "pro_green", "pro_blue", "pro_purple", "bright".

    - Five color_iwh styles: "iwh_default", "iwh_intense", "iwh_pastel", "iwh_all", "iwh_all_hard".

    - Brewer color scales as specified by `brewer.pal.info`.

    - Any manually specified colors.}

\item{load.cols}{When TRUE, automatically loads pre-stored color information for variables from `seu@misc[["var_colors"]]`.}

\item{ncol}{Specifies the number of columns for display if multiple plots are shown. Default: NULL.}

\item{nrow}{Specifies the number of rows for display if multiple plots are shown. Default: NULL.}

\item{lab_fill}{Label for the figure legend. Default: 'group'.}

\item{scales}{Scales parameter passed to \code{\link[ggplot2:facet_wrap]{ggplot2::facet_wrap()}}. Default: 'free_y'.}

\item{style}{Plot style: "fill" (default) uses filled violins with group colors, "outline" uses white fill with colored outlines.}

\item{violin}{Indicates whether to generate a violin plot. Default: TRUE.}

\item{box}{Indicates whether to depict a box plot. Default: TRUE.}

\item{width}{Width of the box plot. Default: 0.9.}

\item{show.mean}{Logical value indicating whether to show mean and median lines. This is particularly useful for genes with low expression levels where the median and box plot quartiles might overlap at zero, making it difficult to interpret differences between groups. Default is FALSE.}

\item{mean_colors}{Vector of two colors for mean and median lines respectively. Default is c("red", "blue").}

\item{pt}{Indicates if points should be plotted. Default: TRUE.}

\item{hide.outlier}{Conceals outlier points from the box plot. Default: FALSE.}

\item{pt.style}{Position adjustment. Default choices: "jitter", "quasirandom".}

\item{pt.size}{Point size setting. Default: 0.2.}

\item{pt.alpha}{Adjusts the transparency of points. Default: 1.}

\item{strip.position}{Positions the strip ("top" (default), "bottom", "left", or "right"). Only used when `f2 = NULL`.}

\item{stat.method}{Determines if pairwise statistics are added to the plot. Either "wilcox.test" or "t.test". Default: "none".}

\item{stats.method}{Alias for \code{stat.method}. Provided for convenience but \code{stat.method} is preferred.
When both are provided, \code{stats.method} takes precedence.}

\item{p.adjust.method}{Method for adjusting p-values, especially when conducting multiple pairwise tests or dealing with multiple grouping variables. Options include "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", and "none". Note: Adjustments are independently conducted for each variable in formulas containing multiple variables. Default: 'holm'.}

\item{label}{Specifies label type. Options include "p.signif" (showing significance levels), "p.format" (formatted p value), or "p", "p.adj". Default: "p.signif".}

\item{comparisons}{List of length-2 vectors, each containing either names of two x-axis values or two integers pointing to groups of interest for comparison. Default: all groups.}

\item{hide.ns}{If TRUE, the 'ns' symbol is concealed when displaying significance levels. Default: TRUE.}

\item{step.increase}{Numeric vector denoting the increase in fraction of total height for each additional comparison, minimizing overlap. Default: 0.12.}

\item{tip.length}{Numeric vector indicating the fraction of total height the bar descends to specify the exact column. For a line display instead of a bracket, set to 0. Default: 0.03.}

\item{angle}{Angle for label rotation. If NULL, automatically determined based on label length. Default: NULL.}

\item{hjust}{Horizontal justification of labels. If NULL, automatically determined based on angle. Default: NULL.}

\item{vjust}{Vertical justification of labels. If NULL, automatically determined based on angle. Default: NULL.}

\item{matr}{A matrix or data frame with rows as features and columns as cells.}

\item{f}{A factor or vector indicating the identity of each cell. Should match the column length of `matr`.}

\item{f2}{A factor or vector akin to `f` for splitting the violin plots. Default: NULL.}

\item{t}{If the matrix has features in columns and cells in rows, transpose the matrix first. Default: FALSE.}
}
\value{
ggplot object

A ggplot object.
}
\description{
Generates advanced violin plots distinct from Seurat's VlnPlot. This improved version offers a more compact design for efficient space utilization, the ability to overlay a boxplot, and convenient inclusion of statistical annotations. The function accommodates input in the form of either a Seurat object or a data frame.
}
\details{
This function provides a range of customization options to generate violin plots, with or without additional graphical elements such as boxplots and points. You can specify features to plot, control the appearance of violin plots, boxplots, and points, adjust point position, group data, split violin plots, selectively use cells, control the column layout of multiple plots, and add statistical annotations. For a detailed overview, refer to the provided examples.

When using the statistical annotation feature (`stat.method`), it's important to be aware that p-values can be artificially inflated in large single-cell datasets due to the high number of cells. This may result in statistically significant differences (small p-values) even when the biological effect size is minimal. We recommend being cautious with statistical interpretations, especially when visual differences are subtle. Consider examining log fold changes (logFC) between groups to better assess the magnitude of biological differences. Additionally, the percentage of cells expressing a marker (similar to the pct.1 and pct.2 values in Seurat's FindMarkers) can be informative - if the difference in percentage between two groups approaches zero, the expression difference may be negligible even with a significant p-value. For a comprehensive visualization of differences between two groups, `WaterfallPlot()` can provide logFC values along with statistical significance. By default, the `VlnPlot2()` function uses the Holm method (`p.adjust.method = "holm"`) to adjust p-values for multiple comparisons, which helps control the family-wise error rate.
}
\examples{
library(Seurat)
library(SeuratExtend)

# Using Seurat object as input:

# Basic violin plot with box plot and points:
genes <- c("CD3D","CD14","CD79A")
VlnPlot2(pbmc, features = genes, ncol = 1)

# Without violin plot, only box plot, and use quasirandom style for point position adjustment:
VlnPlot2(pbmc, features = genes, violin = F, pt.style = "quasirandom", ncol = 1)

# Hide points but display outlier points of the box plot:
VlnPlot2(pbmc, features = genes, pt = FALSE, ncol = 1)

# When hiding points, outliers are shown by default (recommended). However, outliers can be hidden for a cleaner appearance:
VlnPlot2(pbmc, features = genes, pt = FALSE, hide.outlier = T, ncol = 1)

# Using the outline style instead of filled violins:
VlnPlot2(pbmc, features = genes, style = "outline", ncol = 1)

# Group by cluster and split each cluster by samples:
VlnPlot2(pbmc, features = genes, group.by = "cluster", split.by = "orig.ident")

# For genes with low expression where boxplot might be hard to interpret
# (e.g., when median and quartiles overlap at zero),
# you can add mean/median lines for better visualization:
lowExprGenes <- c("CCR7", "IL7R", "TCF7")
VlnPlot2(pbmc, features = lowExprGenes, show.mean = TRUE, cols = "light")

# Display only cells from certain subtypes (e.g. B cell, CD14+ Mono, and CD8 T cell), and arrange plots in 3 columns:
cells <- colnames(pbmc)[pbmc$cluster \%in\% c("B cell", "Mono CD14", "CD8 T cell")]
VlnPlot2(pbmc, features = genes, group.by = "cluster", cells = cells)

# Add statistical annotations using the Wilcoxon test for pairwise comparisons and hide non-significant results:
VlnPlot2(pbmc, features = genes, group.by = "cluster", cell = cells,
         stat.method = "wilcox.test", hide.ns = TRUE)

# Display statistics comparing only the specified clusters using a t-test:
VlnPlot2(pbmc, features = genes, group.by = "cluster", cell = cells,
         stat.method = "t.test", comparisons = list(c(1,2), c(1,3)), hide.ns = FALSE)

# Using a matrix as input:
# For instance, after performing Geneset Enrichment Analysis (GSEA) using the Hallmark 50 geneset to obtain the AUCell matrix:
pbmc <- GeneSetAnalysis(pbmc, genesets = hall50$human)
matr <- pbmc@misc$AUCell$genesets

# Create violin plots for the first three pathways:
VlnPlot2(matr[1:3,], f = pbmc$cluster, ncol = 1)
}
